@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     AccountScopeType,
@@ -36,42 +36,42 @@ from .type_defs import (
     AnomalyMonitorTypeDef,
     AnomalySubscriptionTypeDef,
     CostCategoryRuleTypeDef,
-    CreateAnomalyMonitorResponseResponseTypeDef,
-    CreateAnomalySubscriptionResponseResponseTypeDef,
-    CreateCostCategoryDefinitionResponseResponseTypeDef,
+    CreateAnomalyMonitorResponseTypeDef,
+    CreateAnomalySubscriptionResponseTypeDef,
+    CreateCostCategoryDefinitionResponseTypeDef,
     DateIntervalTypeDef,
-    DeleteCostCategoryDefinitionResponseResponseTypeDef,
-    DescribeCostCategoryDefinitionResponseResponseTypeDef,
+    DeleteCostCategoryDefinitionResponseTypeDef,
+    DescribeCostCategoryDefinitionResponseTypeDef,
     ExpressionTypeDef,
-    GetAnomaliesResponseResponseTypeDef,
-    GetAnomalyMonitorsResponseResponseTypeDef,
-    GetAnomalySubscriptionsResponseResponseTypeDef,
-    GetCostAndUsageResponseResponseTypeDef,
-    GetCostAndUsageWithResourcesResponseResponseTypeDef,
-    GetCostCategoriesResponseResponseTypeDef,
-    GetCostForecastResponseResponseTypeDef,
-    GetDimensionValuesResponseResponseTypeDef,
-    GetReservationCoverageResponseResponseTypeDef,
-    GetReservationPurchaseRecommendationResponseResponseTypeDef,
-    GetReservationUtilizationResponseResponseTypeDef,
-    GetRightsizingRecommendationResponseResponseTypeDef,
-    GetSavingsPlansCoverageResponseResponseTypeDef,
-    GetSavingsPlansPurchaseRecommendationResponseResponseTypeDef,
-    GetSavingsPlansUtilizationDetailsResponseResponseTypeDef,
-    GetSavingsPlansUtilizationResponseResponseTypeDef,
-    GetTagsResponseResponseTypeDef,
-    GetUsageForecastResponseResponseTypeDef,
+    GetAnomaliesResponseTypeDef,
+    GetAnomalyMonitorsResponseTypeDef,
+    GetAnomalySubscriptionsResponseTypeDef,
+    GetCostAndUsageResponseTypeDef,
+    GetCostAndUsageWithResourcesResponseTypeDef,
+    GetCostCategoriesResponseTypeDef,
+    GetCostForecastResponseTypeDef,
+    GetDimensionValuesResponseTypeDef,
+    GetReservationCoverageResponseTypeDef,
+    GetReservationPurchaseRecommendationResponseTypeDef,
+    GetReservationUtilizationResponseTypeDef,
+    GetRightsizingRecommendationResponseTypeDef,
+    GetSavingsPlansCoverageResponseTypeDef,
+    GetSavingsPlansPurchaseRecommendationResponseTypeDef,
+    GetSavingsPlansUtilizationDetailsResponseTypeDef,
+    GetSavingsPlansUtilizationResponseTypeDef,
+    GetTagsResponseTypeDef,
+    GetUsageForecastResponseTypeDef,
     GroupDefinitionTypeDef,
-    ListCostCategoryDefinitionsResponseResponseTypeDef,
-    ProvideAnomalyFeedbackResponseResponseTypeDef,
+    ListCostCategoryDefinitionsResponseTypeDef,
+    ProvideAnomalyFeedbackResponseTypeDef,
     RightsizingRecommendationConfigurationTypeDef,
     ServiceSpecificationTypeDef,
     SortDefinitionTypeDef,
     SubscriberTypeDef,
     TotalImpactFilterTypeDef,
-    UpdateAnomalyMonitorResponseResponseTypeDef,
-    UpdateAnomalySubscriptionResponseResponseTypeDef,
-    UpdateCostCategoryDefinitionResponseResponseTypeDef,
+    UpdateAnomalyMonitorResponseTypeDef,
+    UpdateAnomalySubscriptionResponseTypeDef,
+    UpdateCostCategoryDefinitionResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -105,41 +105,46 @@ class Exceptions:
     UnresolvableUsageUnitException: Type[BotocoreClientError]
 
 
-class CostExplorerClient:
+class CostExplorerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        CostExplorerClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#can_paginate)
         """
 
     def create_anomaly_monitor(
         self, *, AnomalyMonitor: "AnomalyMonitorTypeDef"
-    ) -> CreateAnomalyMonitorResponseResponseTypeDef:
+    ) -> CreateAnomalyMonitorResponseTypeDef:
         """
         Creates a new cost anomaly detection monitor with the requested type and monitor
         specification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_anomaly_monitor)
         """
 
     def create_anomaly_subscription(
         self, *, AnomalySubscription: "AnomalySubscriptionTypeDef"
-    ) -> CreateAnomalySubscriptionResponseResponseTypeDef:
+    ) -> CreateAnomalySubscriptionResponseTypeDef:
         """
         Adds a subscription to a cost anomaly detection monitor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_anomaly_subscription)
         """
 
@@ -150,11 +155,11 @@ class CostExplorerClient:
         RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: List["CostCategoryRuleTypeDef"],
         DefaultValue: str = None
-    ) -> CreateCostCategoryDefinitionResponseResponseTypeDef:
+    ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
         Creates a new Cost Category with the requested name and rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_cost_category_definition)
         """
 
@@ -162,7 +167,7 @@ class CostExplorerClient:
         """
         Deletes a cost anomaly monitor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_anomaly_monitor)
         """
 
@@ -170,28 +175,28 @@ class CostExplorerClient:
         """
         Deletes a cost anomaly subscription.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_anomaly_subscription)
         """
 
     def delete_cost_category_definition(
         self, *, CostCategoryArn: str
-    ) -> DeleteCostCategoryDefinitionResponseResponseTypeDef:
+    ) -> DeleteCostCategoryDefinitionResponseTypeDef:
         """
         Deletes a Cost Category.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_cost_category_definition)
         """
 
     def describe_cost_category_definition(
         self, *, CostCategoryArn: str, EffectiveOn: str = None
-    ) -> DescribeCostCategoryDefinitionResponseResponseTypeDef:
+    ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
         Returns the name, ARN, rules, definition, and effective dates of a Cost Category
         that's defined in the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#describe_cost_category_definition)
         """
 
@@ -205,7 +210,7 @@ class CostExplorerClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#generate_presigned_url)
         """
 
@@ -218,22 +223,22 @@ class CostExplorerClient:
         TotalImpact: "TotalImpactFilterTypeDef" = None,
         NextPageToken: str = None,
         MaxResults: int = None
-    ) -> GetAnomaliesResponseResponseTypeDef:
+    ) -> GetAnomaliesResponseTypeDef:
         """
         Retrieves all of the cost anomalies detected on your account, during the time
         period specified by the `DateInterval` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_anomalies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_anomalies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomalies)
         """
 
     def get_anomaly_monitors(
         self, *, MonitorArnList: List[str] = None, NextPageToken: str = None, MaxResults: int = None
-    ) -> GetAnomalyMonitorsResponseResponseTypeDef:
+    ) -> GetAnomalyMonitorsResponseTypeDef:
         """
         Retrieves the cost anomaly monitor definitions for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomaly_monitors)
         """
 
@@ -244,11 +249,11 @@ class CostExplorerClient:
         MonitorArn: str = None,
         NextPageToken: str = None,
         MaxResults: int = None
-    ) -> GetAnomalySubscriptionsResponseResponseTypeDef:
+    ) -> GetAnomalySubscriptionsResponseTypeDef:
         """
         Retrieves the cost anomaly subscription objects for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomaly_subscriptions)
         """
 
@@ -261,11 +266,11 @@ class CostExplorerClient:
         Filter: "ExpressionTypeDef" = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None
-    ) -> GetCostAndUsageResponseResponseTypeDef:
+    ) -> GetCostAndUsageResponseTypeDef:
         """
         Retrieves cost and usage metrics for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_and_usage)
         """
 
@@ -278,11 +283,11 @@ class CostExplorerClient:
         Metrics: List[str] = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None
-    ) -> GetCostAndUsageWithResourcesResponseResponseTypeDef:
+    ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
         Retrieves cost and usage metrics with resources for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_and_usage_with_resources)
         """
 
@@ -296,11 +301,11 @@ class CostExplorerClient:
         SortBy: List["SortDefinitionTypeDef"] = None,
         MaxResults: int = None,
         NextPageToken: str = None
-    ) -> GetCostCategoriesResponseResponseTypeDef:
+    ) -> GetCostCategoriesResponseTypeDef:
         """
         Retrieves an array of Cost Category names and values incurred cost.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_categories)
         """
 
@@ -312,12 +317,12 @@ class CostExplorerClient:
         Granularity: GranularityType,
         Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None
-    ) -> GetCostForecastResponseResponseTypeDef:
+    ) -> GetCostForecastResponseTypeDef:
         """
         Retrieves a forecast for how much Amazon Web Services predicts that you will
         spend over the forecast time period that you select, based on your past costs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_forecast)
         """
 
@@ -332,12 +337,12 @@ class CostExplorerClient:
         SortBy: List["SortDefinitionTypeDef"] = None,
         MaxResults: int = None,
         NextPageToken: str = None
-    ) -> GetDimensionValuesResponseResponseTypeDef:
+    ) -> GetDimensionValuesResponseTypeDef:
         """
         Retrieves all available filter values for a specified filter over a period of
         time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_dimension_values)
         """
 
@@ -352,11 +357,11 @@ class CostExplorerClient:
         NextPageToken: str = None,
         SortBy: "SortDefinitionTypeDef" = None,
         MaxResults: int = None
-    ) -> GetReservationCoverageResponseResponseTypeDef:
+    ) -> GetReservationCoverageResponseTypeDef:
         """
         Retrieves the reservation coverage for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_coverage)
         """
 
@@ -373,11 +378,11 @@ class CostExplorerClient:
         ServiceSpecification: "ServiceSpecificationTypeDef" = None,
         PageSize: int = None,
         NextPageToken: str = None
-    ) -> GetReservationPurchaseRecommendationResponseResponseTypeDef:
+    ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
         Gets recommendations for which reservations to purchase.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_purchase_recommendation)
         """
 
@@ -391,11 +396,11 @@ class CostExplorerClient:
         SortBy: "SortDefinitionTypeDef" = None,
         NextPageToken: str = None,
         MaxResults: int = None
-    ) -> GetReservationUtilizationResponseResponseTypeDef:
+    ) -> GetReservationUtilizationResponseTypeDef:
         """
         Retrieves the reservation utilization for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_utilization)
         """
 
@@ -407,12 +412,12 @@ class CostExplorerClient:
         Configuration: "RightsizingRecommendationConfigurationTypeDef" = None,
         PageSize: int = None,
         NextPageToken: str = None
-    ) -> GetRightsizingRecommendationResponseResponseTypeDef:
+    ) -> GetRightsizingRecommendationResponseTypeDef:
         """
         Creates recommendations that help you save cost by identifying idle and
         underutilized Amazon EC2 instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_rightsizing_recommendation)
         """
 
@@ -427,11 +432,11 @@ class CostExplorerClient:
         NextToken: str = None,
         MaxResults: int = None,
         SortBy: "SortDefinitionTypeDef" = None
-    ) -> GetSavingsPlansCoverageResponseResponseTypeDef:
+    ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
         Retrieves the Savings Plans covered for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_coverage)
         """
 
@@ -446,12 +451,12 @@ class CostExplorerClient:
         NextPageToken: str = None,
         PageSize: int = None,
         Filter: "ExpressionTypeDef" = None
-    ) -> GetSavingsPlansPurchaseRecommendationResponseResponseTypeDef:
+    ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
         Retrieves your request parameters, Savings Plan Recommendations Summary and
         Details.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_purchase_recommendation)
         """
 
@@ -462,12 +467,12 @@ class CostExplorerClient:
         Granularity: GranularityType = None,
         Filter: "ExpressionTypeDef" = None,
         SortBy: "SortDefinitionTypeDef" = None
-    ) -> GetSavingsPlansUtilizationResponseResponseTypeDef:
+    ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
         Retrieves the Savings Plans utilization for your account across date ranges with
         daily or monthly granularity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_utilization)
         """
 
@@ -480,12 +485,12 @@ class CostExplorerClient:
         NextToken: str = None,
         MaxResults: int = None,
         SortBy: "SortDefinitionTypeDef" = None
-    ) -> GetSavingsPlansUtilizationDetailsResponseResponseTypeDef:
+    ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
         Retrieves attribute data along with aggregate utilization and savings data for a
         given time period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_utilization_details)
         """
 
@@ -499,11 +504,11 @@ class CostExplorerClient:
         SortBy: List["SortDefinitionTypeDef"] = None,
         MaxResults: int = None,
         NextPageToken: str = None
-    ) -> GetTagsResponseResponseTypeDef:
+    ) -> GetTagsResponseTypeDef:
         """
         Queries for available tag keys and tag values for a specified period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_tags)
         """
 
@@ -515,43 +520,43 @@ class CostExplorerClient:
         Granularity: GranularityType,
         Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None
-    ) -> GetUsageForecastResponseResponseTypeDef:
+    ) -> GetUsageForecastResponseTypeDef:
         """
         Retrieves a forecast for how much Amazon Web Services predicts that you will use
         over the forecast time period that you select, based on your past usage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_usage_forecast)
         """
 
     def list_cost_category_definitions(
         self, *, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
-    ) -> ListCostCategoryDefinitionsResponseResponseTypeDef:
+    ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
         Returns the name, ARN, `NumberOfRules` and effective dates of all Cost
         Categories defined in the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#list_cost_category_definitions)
         """
 
     def provide_anomaly_feedback(
         self, *, AnomalyId: str, Feedback: AnomalyFeedbackTypeType
-    ) -> ProvideAnomalyFeedbackResponseResponseTypeDef:
+    ) -> ProvideAnomalyFeedbackResponseTypeDef:
         """
         Modifies the feedback property of a given cost anomaly.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#provide_anomaly_feedback)
         """
 
     def update_anomaly_monitor(
         self, *, MonitorArn: str, MonitorName: str = None
-    ) -> UpdateAnomalyMonitorResponseResponseTypeDef:
+    ) -> UpdateAnomalyMonitorResponseTypeDef:
         """
         Updates an existing cost anomaly monitor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_anomaly_monitor)
         """
 
@@ -564,11 +569,11 @@ class CostExplorerClient:
         MonitorArnList: List[str] = None,
         Subscribers: List["SubscriberTypeDef"] = None,
         SubscriptionName: str = None
-    ) -> UpdateAnomalySubscriptionResponseResponseTypeDef:
+    ) -> UpdateAnomalySubscriptionResponseTypeDef:
         """
         Updates an existing cost anomaly monitor subscription.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_anomaly_subscription)
         """
 
@@ -579,10 +584,10 @@ class CostExplorerClient:
         RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: List["CostCategoryRuleTypeDef"],
         DefaultValue: str = None
-    ) -> UpdateCostCategoryDefinitionResponseResponseTypeDef:
+    ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
         Updates an existing Cost Category.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_cost_category_definition)
         """
